;; Generated package description from adaptive-wrap.el  -*- no-byte-compile: t -*-
(define-package "adaptive-wrap" "0.8.0.2021011124834" "Smart line-wrapping with wrap-prefix" 'nil :url "https://elpa.gnu.org/packages/adaptive-wrap.html" :authors '(("Stephen Berman" . "stephen.berman@gmx.net") ("Stefan Monnier" . "monnier@iro.umontreal.ca")) :maintainer '("Stephen Berman" . "stephen.berman@gmx.net"))
